/* $Workfile: OsaDef.h $   $Revision: 4 $    $Modtime: 1/30/02 11:33a $  */
#ifndef OSA_DEF_H
#define OSA_DEF_H
/*******************************************************************************

  @doc PublicHwApi OsaDef

  Copyright (C) 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaDef | This file contains macros for the platform
  generic Osa implementation (used by the demo programs).

  @contents2
  OsaDef.h |

  @index func | OsaStd

  @contents2
  Osa Macros | macros for the platform
  generic Osa implementation (used by the demo programs).
  
*******************************************************************************/

// This file is the first to get included, even if you start by including
// one of the other osa headers

#if ( defined(WIN32) && !defined(_WIN32_WCE) )
#define OSA_WIN32 1
#endif

#ifdef __linux__
#define OSA_LINUX 1
#endif

#if defined(_WIN32_WCE)
#define OSA_WINDOWSCE 1
#endif

#if defined(__KERNEL__) || defined(DRIVER) || defined (OSA_DRIVER)
#undef DRIVER
#undef __KERNEL__
#undef OSA_DRIVER
#define DRIVER 1
#define __KERNEL__ 1
#define OSA_DRIVER 1
#endif

#if (OSA_WIN32 + OSA_LINUX + OSA_WINDOWSCE) != 1
#error "One (and only one) of OSA_WIN32 or OSA_LINUX or OSA_WINDOWSCE must be defined to '1'"
#endif

#if OSA_WIN32
#if (OSA_WIN32_NT + OSA_WIN32_WDM) > 1
#error "At the most one of OSA_WIN32_NT and OSA_WIN32_WDM must be defined to '1'"
#endif

#elif OSA_LINUX
#if (OSA_LINUX_INTEL + OSA_LINUX_SPARC + OSA_LINUX_ALPHA) > 1
#error "At the most one of OSA_LINUX_INTEL, OSA_LINUX_SPARC and OSA_LINUX_ALPHA must be defined to '1'"
#endif
#endif

#if defined(_WIN32_WCE)
#include "WindowsCe\OsaWindowsCeDef.h"
#elif OSA_WIN32
#include "W32\OsaWin32Def.h"
#elif OSA_LINUX
#include "Linux/OsaLinuxDef.h"
#else
#error "Must define OSA_WIN32 or OSA_LINUX or OSA_WINDOWSCE"
#endif

#ifndef IN
#define IN
#define OUT
#endif

#define OSA_NULL   0  // Linux messes up the declaration of NULL since Linux kernel headers are C++ unaware

#define OSA_MAX(a,b)  (((a) > (b)) ? (a) : (b))
#define OSA_MIN(a,b)  (((a) < (b)) ? (a) : (b))

typedef OsaInt32    OsaBool32;    // Boolean with guaranteed size
#define  OSA_TRUE  1
#define  OSA_FALSE 0

typedef OsaInt32    OsaEnum32;    // Enum type to use when a guaranteed size is required

// @todo Macro OSA_ENUM_CAST does not need to be part of the API
// All enums must be transferred as OTX_INT32 values in the IO control
// structs. This macro is used to cast them back to enum types on the
// receiving side. The nacro is also used in some other contexts
#if OSA_COMPILE_TYPE_DEBUG_ONLY
#define OSA_ENUM_CAST(EnumType, int32Value) (int32Value)
#define OSA_ENUM_DECL(EnumType) EnumType   
#else
#define OSA_ENUM_CAST(EnumType, int32Value) ((EnumType) int32Value)
#define OSA_ENUM_DECL(EnumType) OsaEnum32   // Macro used to indicate which enum type is really intended
#endif

typedef union OsaDateTime {
  struct {
    OsaUint32 nLow;
    OsaUint32 nHigh;
  } sUint32;
  OsaUint64 nUint64;
} OsaDateTime;


/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif // OSA_DEF_H
